==> haskell-lens-aeson-1.0.2-179-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lens-aeson
version: 1.0.2
id: lens-aeson-1.0.2-FCXsAxh8qXX77x1Oo9pd6e
key: lens-aeson-1.0.2-FCXsAxh8qXX77x1Oo9pd6e
license: MIT
copyright: Copyright (C) 2012 Paul Wilson
           Copyright (C) 2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/lens/lens-aeson/
synopsis: Law-abiding lenses for aeson
description:
    Law-abiding lenses for aeson
category: Numeric
abi: 0c3f1192ae7cc9b6cfeba305ee7bcbba
exposed: True
exposed-modules:
    Data.Aeson.Lens
import-dirs: /usr/lib/ghc-8.6.5/site-local/lens-aeson-1.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/lens-aeson-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/lens-aeson-1.0.2
hs-libraries: HSlens-aeson-1.0.2-FCXsAxh8qXX77x1Oo9pd6e
depends:
    aeson-1.4.6.0-IYkWE2kAqOg3BtypRoad0s
    attoparsec-0.13.2.3-7zk58GWWjTj9W2Qd2JktwB base-4.12.0.0
    bytestring-0.10.8.2 lens-4.17.1-7S5lGb7ZxVusQDqQpE4dD
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    unordered-containers-0.2.10.0-98MsUmwXpKo1DE5wGxzrlx
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-lens-aeson/html/lens-aeson.haddock
haddock-html: /usr/share/doc/haskell-lens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lens-aeson-1.0.2-180-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lens-aeson
version: 1.0.2
id: lens-aeson-1.0.2-A3YQrpAPEiN2U45RMpx97b
key: lens-aeson-1.0.2-A3YQrpAPEiN2U45RMpx97b
license: MIT
copyright: Copyright (C) 2012 Paul Wilson
           Copyright (C) 2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/lens/lens-aeson/
synopsis: Law-abiding lenses for aeson
description:
    Law-abiding lenses for aeson
category: Numeric
abi: 2a5eecabe0f9bdb26539aa5192bfc26b
exposed: True
exposed-modules:
    Data.Aeson.Lens
import-dirs: /usr/lib/ghc-8.6.5/site-local/lens-aeson-1.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/lens-aeson-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/lens-aeson-1.0.2
hs-libraries: HSlens-aeson-1.0.2-A3YQrpAPEiN2U45RMpx97b
depends:
    aeson-1.4.6.0-ByJnT4jukmB1Ih4DIu8bQB
    attoparsec-0.13.2.3-8w0M5Ys1O3I8OHsDdXIpYC base-4.12.0.0
    bytestring-0.10.8.2 lens-4.17.1-FKLB3klUZnP1VUCoa2NPRL
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    unordered-containers-0.2.10.0-EKmGslSZSRGGEQm9fn2qPS
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-lens-aeson/html/lens-aeson.haddock
haddock-html: /usr/share/doc/haskell-lens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
